@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---         Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  QRW Software
+--      Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-10-06 08:06:23 -0600 (Tue, 06 Oct 2009) $
---   $Revision: 4384 $
+--   $Date: 2010-09-12 07:13:48 -0600 (Sun, 12 Sep 2010) $
+--   $Revision: 4720 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -87,7 +87,7 @@ extern bool nwos_is_writable(void);
 extern bool nwos_backup_is_enabled(void);
 extern const char* nwos_archive_version(void);
 
-//extern bool nwos_find_class_definition(char* name, ObjRef* class_ref);
+extern bool nwos_find_class_definition(char* name, ObjRef* class_ref);
 extern bool nwos_find_public_class_definition(char* name, ObjRef* class_ref);
 extern bool nwos_find_private_class_definition(char* name, ObjRef* class_ref);
 extern ObjCreateResult nwos_find_or_create_private_class_definition(char* name_of_class, ObjRef* ref);
@@ -224,14 +224,20 @@ extern bool nwos_file_path_to_string(ObjRef* ref, char* string, size_t size);
 extern int  nwos_number_of_files_for_path(ObjRef* path_ref);
 extern uint32 nwos_estimate_blocks_for_file(const char* path);
 extern bool nwos_file_path_to_path_and_file_association(ObjRef* path_ref, int index, ObjRef* assoc_ref);
-extern bool nwos_find_md5(uint8 md5[16], ObjRef* ref);
+extern bool nwos_find_md5(uint8 md5[MD5_DIGEST_SIZE], ObjRef* ref);
+extern bool nwos_find_sha1(uint8 sha1[SHA1_DIGEST_SIZE], ObjRef* ref);
+extern bool nwos_find_sha256(uint8 sha256[SHA256_DIGEST_SIZE], ObjRef* ref);
+extern bool nwos_find_sha512(uint8 sha512[SHA512_DIGEST_SIZE], ObjRef* ref);
 extern bool nwos_find_path_and_file_association(ObjRef* path_ref, ObjRef* file_ref, TimeStamp mod_time, ObjRef* ref);
-typedef enum { MatchAll, IgnoreTime } MatchCode;
+typedef enum { MatchAll=0x00, IgnoreTime=0x01, IgnoreVfat=0x02, IgnorePath=0x04, IgnoreName=0x08 } MatchCode;
 extern bool nwos_find_matching_path_and_file_association(const char* path, const char* file, ObjRef* ref, MatchCode match);
 extern CheckFileResult nwos_check_file_checksums(const char* path);
 extern bool nwos_file_is_stored(ObjRef* association_ref);  /* returns true if data stored in system */
 extern bool nwos_file_has_backup(ObjRef* association_ref);  /* returns true if file is on a backup disc */
 extern ObjCreateResult nwos_create_file_with_only_md5(const char* file_name, uint8 md5_digest[MD5_DIGEST_SIZE], ObjRef* ref);
+extern ObjCreateResult nwos_create_file_with_duplicate_md5(const char* file_name, uint8 md5_digest[MD5_DIGEST_SIZE], ObjRef* ref);
+extern ObjCreateResult nwos_create_file_with_only_sha1(const char* file_name, uint8 sha1_digest[SHA1_DIGEST_SIZE], ObjRef* ref);
+extern ObjCreateResult nwos_create_file_with_duplicate_sha1(const char* file_name, uint8 sha1_digest[SHA1_DIGEST_SIZE], ObjRef* ref);
 extern ObjCreateResult nwos_add_info_to_existing_file(const char* file_name, ObjRef* ref);
 extern ObjCreateResult nwos_create_file_without_storing_data(const char* path, const char* file_name, ObjRef* ref);
 extern ObjCreateResult nwos_create_file(const char* path, ObjRef* ref, bool allow_multiple_paths);
