@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-02-28 09:20:40 -0700 (Sun, 28 Feb 2010) $
---   $Revision: 4602 $
+--   $Date: 2010-07-08 21:51:35 -0600 (Thu, 08 Jul 2010) $
+--   $Revision: 4669 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -298,9 +298,7 @@ int main(int argc, char* argv[])
 	{
 	    if (strcmp(argv[i], "--add-revision") == 0)
 	    {
-		i++;
-
-		if (i == argc || argv[i][0] == '-')
+		if ((i+1) == argc || argv[i+1][0] == '-')
 		{
 		    fprintf(stderr, "Error: a file must be specified after --add-revision\n");
 		    exit(1);
