@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-01-20 08:10:57 -0700 (Wed, 20 Jan 2010) $
---   $Revision: 4465 $
+--   $Date: 2010-06-24 07:35:28 -0600 (Thu, 24 Jun 2010) $
+--   $Revision: 4657 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -597,23 +597,34 @@ int main(int argc, char* argv[])
 
 	/* first make sure the references all match */
 
-	for (i = 0; i < nwos_used_private_chunks; i++)
+	for (i = 0, j = 0; i < used_chunks && j < nwos_used_private_chunks; i++, j++)
 	{
-	    if (chunk_info[i].ref != nwos_chunk_info[i].ref) break;
+	    if (chunk_info[i].ref != nwos_chunk_info[j].ref)
+	    {
+		if ((chunk_info[i].flags_used & CHUNK_INFO_USED_MASK) == 0)   /* skip over empty */
+		{
+		    j--;
+		}
+		else
+		{
+		    break;
+		}
+	    }
+	    else   /* references match */
+	    {
+		if ((chunk_info[i].flags_used & CHUNK_INFO_USED_MASK) != (nwos_chunk_info[j].flags_used & CHUNK_INFO_USED_MASK)) num_chunks_block_size_mismatch++;
+		if (memcmp(chunk_info[i].md5_digest, nwos_chunk_info[j].md5_digest, MD5_DIGEST_SIZE) != 0) num_chunks_md5_mismatch++;
+	    }
 	}
 
-	if (i < nwos_used_private_chunks)   /* refs didn't all match */
+	if (i < used_chunks || j < nwos_used_private_chunks)   /* refs didn't all match */
 	{
-	    printf("Reference mismatch - index: %d  %s: %llx  %s: %llx\n", i, source, chunk_info[i].ref, destination, nwos_chunk_info[i].ref);
+	    printf("Reference mismatch - %s [%d]: %llx    %s [%d]: %llx\n",
+		   source,      i, i < used_chunks ? chunk_info[i].ref : 0,
+		   destination, j, j < nwos_used_private_chunks ? nwos_chunk_info[j].ref : 0);
 	}
 	else
 	{
-	    for (i = 0; i < nwos_used_private_chunks; i++)
-	    {
-		if ((chunk_info[i].flags_used & CHUNK_INFO_USED_MASK) != (nwos_chunk_info[i].flags_used & CHUNK_INFO_USED_MASK)) num_chunks_block_size_mismatch++;
-		if (memcmp(chunk_info[i].md5_digest, nwos_chunk_info[i].md5_digest, MD5_DIGEST_SIZE) != 0) num_chunks_md5_mismatch++;
-	    }
-
 	    printf("Number of chunks with block counts that mismatch:  %u\n", num_chunks_block_size_mismatch);
 	    printf("Number of chunks with MD5 checksums that mismatch: %u\n", num_chunks_md5_mismatch);
 	}
