@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               Copyright (C) 2007, 2008, 2009, 2010  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-10-06 08:06:23 -0600 (Tue, 06 Oct 2009) $
---   $Revision: 4384 $
+--   $Date: 2010-09-05 12:13:19 -0600 (Sun, 05 Sep 2010) $
+--   $Revision: 4672 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -667,7 +667,7 @@ void nwos_terminate_backup(bool modified, Disk_Header* disk_header)
 	    {
 		start_time = time(NULL);
 		sort_file();
-		fprintf(stderr, "Sort time: %ld seconds\n", time(NULL) - start_time);
+		fprintf(stderr, "Sort time: %u seconds\n", (uint32)(time(NULL) - start_time));
 	    }
 
 	    if (close(backup_file_desc) < 0)
