@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-01-17 11:00:24 -0700 (Sun, 17 Jan 2010) $
---   $Revision: 4456 $
+--   $Date: 2010-03-16 07:53:57 -0600 (Tue, 16 Mar 2010) $
+--   $Revision: 4630 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -158,7 +158,7 @@ void nwos_log(char* str)
 	    *p = '\0';
 	    if (mkdir(path, 0755) != 0 && errno != EEXIST)
 	    {
-		perror(p);
+		perror(path);
 		exit(1);
 	    }
 	    *p = '/';
