@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-01-04 12:55:02 -0700 (Mon, 04 Jan 2010) $
---   $Revision: 4431 $
+--   $Date: 2010-02-04 06:59:39 -0700 (Thu, 04 Feb 2010) $
+--   $Revision: 4535 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -146,6 +146,8 @@ void nwos_encode_variable_sized_count(uint32 count, uint8 result[4])
 /* Root object ID transformation */
 /*********************************/
 
+#ifndef DISABLE_SECURITY_FEATURES
+
 static bool is_binary_number(uint n)
 {
     uint u;
@@ -174,6 +176,8 @@ static void nwos_transform_root(ObjRef* dst_ref, ObjRef* src_ref, int num)
     dst_ref->id[0] = src_ref->id[0] + (num << shift_count);
 }
 
+#endif /* DISABLE_SECURITY_FEATURES */
+
 
 /**********************************/
 /* Initialization and Termination */
@@ -213,6 +217,14 @@ void nwos_initialize_objectify(AccessType type, const char* path)
 #ifndef PUBLIC_MODE
     else
     {
+#ifdef DISABLE_SECURITY_FEATURES
+	root_object_ref.id[0] = 0x10;
+	root_object_ref.id[1] = 0x00;
+	root_object_ref.id[2] = 0x00;
+	root_object_ref.id[3] = 0x00;
+
+	assert(nwos_set_root_object(&root_object_ref));
+#else
 	for (attempt = 0; attempt < NUM_ATTEMPTS; attempt++)
 	{
 	    nwos_get_key_from_password(big_key, sizeof(big_key));
@@ -237,6 +249,7 @@ void nwos_initialize_objectify(AccessType type, const char* path)
 	    fprintf(stderr, "\n");
 	    exit(1);
 	}
+#endif  /* DISABLE_SECURITY_FEATURES */
     }
 #endif
 }
@@ -289,7 +302,12 @@ void nwos_create_root(void)
 
     assert(nwos_find_public_class_definition("ROOT", &public_root_class_ref));
 
-
+#ifdef DISABLE_SECURITY_FEATURES
+    private_root_obj_ref.id[0] = 0x10;
+    private_root_obj_ref.id[1] = 0x00;
+    private_root_obj_ref.id[2] = 0x00;
+    private_root_obj_ref.id[3] = 0x00;
+#else
     while (true)
     {
 	assert(sizeof(big_key_1) == sizeof(big_key_2));
@@ -345,6 +363,7 @@ void nwos_create_root(void)
 	    fprintf(stderr, "\nThat pass phrase cannot be used, try a different one.\n\n");
 	}
     }
+#endif  /* DISABLE_SECURITY_FEATURES */
 
     /* create the private root object */
 
