@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-02-04 06:13:27 -0700 (Thu, 04 Feb 2010) $
---   $Revision: 4534 $
+--   $Date: 2010-04-10 05:05:09 -0600 (Sat, 10 Apr 2010) $
+--   $Revision: 4653 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -404,7 +404,7 @@ void nwos_get_key_from_password(uint8 key[], size_t key_size)
 		    chars_read--;
 		}
 
-		if (buffer[num_chars] == '\n')
+		if (chars_read > 0 && buffer[num_chars] == '\n')
 		{
 		    if (display_mode == Show)
 		    {
