@@ -39,8 +39,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2010-01-30 08:57:28 -0700 (Sat, 30 Jan 2010) $
-#   $Revision: 4510 $
+#   $Date: 2010-09-12 14:05:28 -0600 (Sun, 12 Sep 2010) $
+#   $Revision: 4729 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -986,33 +986,18 @@ echo "--------------------------------------------------"
 
 echo "This is test #1" > test2.txt
 
-if $EXEC/src/apps/file/file-import --add-revision test2.txt > /tmp/test8r.out; then
+$EXEC/src/apps/file/file-verify test2.txt
+
+if ! $EXEC/src/apps/file/file-import --add-revision test2.txt > /tmp/test8r.out; then
    echo ""
-   echo "file-import --add-revision new file succeeded"
+   echo "file-import --add-revision file with same data as another failed"
    echo ""
    exit 1
 fi
 
-if ! grep -q "duplicate files: 1" /tmp/test8r.out; then
+if ! grep -q "new revisions:   1" /tmp/test8r.out; then
    echo ""
-   echo "did not report 1 duplicate file"
-   echo ""
-   exit 1
-fi
-
-
-echo "This is test #1" > test3.txt
-
-if $EXEC/src/apps/file/file-import --add-revision test2.txt > /tmp/test8r.out; then
-   echo ""
-   echo "file-import --add-revision new file succeeded"
-   echo ""
-   exit 1
-fi
-
-if ! grep -q "duplicate files: 1" /tmp/test8r.out; then
-   echo ""
-   echo "did not report 1 duplicate file"
+   echo "did not report 1 new revision file"
    echo ""
    exit 1
 fi
@@ -1022,7 +1007,7 @@ echo "-------------------------------------------------"
 echo " Case 11: add revision but path doesn't exist..."
 echo "-------------------------------------------------"
 
-echo "This is test #3" > test3.txt
+echo "This is test #1" > test3.txt
 
 if $EXEC/src/apps/file/file-import --add-revision test3.txt > /tmp/test3r.out; then
    echo ""
